@@ -6,11 +6,12 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 # 
+use 5.008;
 use warnings;
 use strict;
 
 package Audio::MPD::Collection;
-our $VERSION = '0.19.8';
+our $VERSION = '0.19.9';
 
 
 # ABSTRACT: class to query MPD's collection
@@ -320,7 +321,7 @@ Audio::MPD::Collection - class to query MPD's collection
 
 =head1 VERSION
 
-version 0.19.8
+version 0.19.9
 
 =head1 SYNOPSIS
 
@@ -328,7 +329,7 @@ version 0.19.8
 
 =head1 DESCRIPTION
 
-C<Audio::MPD::Collection> is a class meant to access & query MPD's
+L<Audio::MPD::Collection> is a class meant to access & query MPD's
 collection. You will be able to use those high-level methods instead
 of using the low-level methods provided by mpd itself.
 
@@ -340,13 +341,13 @@ of using the low-level methods provided by mpd itself.
 
 =item new( $mpd )
 
-This will create the object, holding a back-reference to the C<Audio::MPD>
+This will create the object, holding a back-reference to the L<Audio::MPD>
 object itself (for communication purposes). But in order to play safe and
 to free the memory in time, this reference is weakened.
 
 Note that you're not supposed to call this constructor yourself, an
-C<Audio::MPD::Collection> is automatically created for you during the creation
-of an C<Audio::MPD> object.
+L<Audio::MPD::Collection> is automatically created for you during the creation
+of an L<Audio::MPD> object.
 
 =back 
 
@@ -356,7 +357,7 @@ of an C<Audio::MPD> object.
 
 =item $coll->all_items( [$path] )
 
-Return B<all> C<Audio::MPD::Common::Item>s (both songs & directories)
+Return B<all> L<Audio::MPD::Common::Item>s (both songs & directories)
 currently known by mpd.
 
 If C<$path> is supplied (relative to mpd root), restrict the retrieval to
@@ -364,13 +365,13 @@ songs and dirs in this directory.
 
 =item $coll->all_items_simple( [$path] )
 
-Return B<all> C<Audio::MPD::Common::Item>s (both songs & directories)
+Return B<all> L<Audio::MPD::Common::Item>s (both songs & directories)
 currently known by mpd.
 
 If C<$path> is supplied (relative to mpd root), restrict the retrieval to
 songs and dirs in this directory.
 
-B</!\ Warning>: the C<Audio::MPD::Common::Item::Song> objects will only
+B</!\ Warning>: the L<Audio::MPD::Common::Item::Song> objects will only
 have their tag C<file> filled. Any other tag will be empty, so don't use
 this sub for any other thing than a quick scan!
 
@@ -389,7 +390,7 @@ Note that this sub does not work recusrively on all directories.
 
 =item $coll->all_songs( [$path] )
 
-Return B<all> C<Audio::MPD::Common::Item::Song>s currently known by mpd.
+Return B<all> L<Audio::MPD::Common::Item::Song>s currently known by mpd.
 
 If C<$path> is supplied (relative to mpd root), restrict the retrieval to
 songs and dirs in this directory.
@@ -422,11 +423,11 @@ Return the list of all playlists (strings) currently known by mpd.
 
 =item $coll->song( $path )
 
-Return the C<Audio::MPD::Common::Item::Song> which correspond to C<$path>.
+Return the L<Audio::MPD::Common::Item::Song> which correspond to C<$path>.
 
 =item $coll->songs_with_filename_partial( $string )
 
-Return the C<Audio::MPD::Common::Item::Song>s containing C<$string> in
+Return the L<Audio::MPD::Common::Item::Song>s containing C<$string> in
 their path.
 
 =back 
@@ -442,30 +443,30 @@ participated.
 
 =item $coll->songs_by_artist( $artist )
 
-Return all C<Audio::MPD::Common::Item::Song>s performed by C<$artist>.
+Return all L<Audio::MPD::Common::Item::Song>s performed by C<$artist>.
 
 =item $coll->songs_by_artist_partial( $string )
 
-Return all C<Audio::MPD::Common::Item::Song>s performed by an artist
+Return all L<Audio::MPD::Common::Item::Song>s performed by an artist
 with C<$string> in her name.
 
 =item $coll->songs_from_album( $album )
 
-Return all C<Audio::MPD::Common::Item::Song>s appearing in C<$album>.
+Return all L<Audio::MPD::Common::Item::Song>s appearing in C<$album>.
 
 =item $coll->songs_from_album_partial( $string )
 
-Return all C<Audio::MPD::Common::Item::Song>s appearing in album
+Return all L<Audio::MPD::Common::Item::Song>s appearing in album
 containing C<$string>.
 
 =item $coll->songs_with_title( $title )
 
-Return all C<Audio::MPD::Common::Item::Song>s which title is exactly
+Return all L<Audio::MPD::Common::Item::Song>s which title is exactly
 C<$title>.
 
 =item $coll->songs_with_title_partial( $string )
 
-Return all C<Audio::MPD::Common::Item::Song>s where C<$string> is part
+Return all L<Audio::MPD::Common::Item::Song>s where C<$string> is part
 of the title.
 
 =back 
