@@ -6,11 +6,12 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 # 
+use 5.008;
 use warnings;
 use strict;
 
 package Audio::MPD::Playlist;
-our $VERSION = '0.19.8';
+our $VERSION = '0.19.9';
 
 
 # ABSTRACT: class to mess MPD's playlist
@@ -268,7 +269,7 @@ Audio::MPD::Playlist - class to mess MPD's playlist
 
 =head1 VERSION
 
-version 0.19.8
+version 0.19.9
 
 =head1 SYNOPSIS
 
@@ -276,7 +277,7 @@ version 0.19.8
 
 =head1 DESCRIPTION
 
-C<Audio::MPD::Playlist> is a class meant to access & update MPD's
+L<Audio::MPD::Playlist> is a class meant to access & update MPD's
 playlist.
 
 =head1 PUBLIC METHODS
@@ -287,13 +288,13 @@ playlist.
 
 =item new( $mpd )
 
-This will create the object, holding a back-reference to the C<Audio::MPD>
+This will create the object, holding a back-reference to the L<Audio::MPD>
 object itself (for communication purposes). But in order to play safe and
 to free the memory in time, this reference is weakened.
 
 Note that you're not supposed to call this constructor yourself, an
-C<Audio::MPD::Playlist> is automatically created for you during the creation
-of an C<Audio::MPD> object.
+L<Audio::MPD::Playlist> is automatically created for you during the creation
+of an L<Audio::MPD> object.
 
 =back 
 
@@ -303,13 +304,13 @@ of an C<Audio::MPD> object.
 
 =item $pl->as_items()
 
-Return an array of C<Audio::MPD::Common::Item::Song>s, one for each of the
+Return an array of L<Audio::MPD::Common::Item::Song>s, one for each of the
 songs in the current playlist.
 
 =item $pl->items_changed_since( $plversion )
 
-Return a list with all the songs (as AMC::Item::Song objects) added to
-the playlist since playlist C<$plversion>.
+Return a list with all the songs (as L<Audio::MPD::Common::Item::Song> objects)
+added to the playlist since playlist C<$plversion>.
 
 =back 
 
